//******************************************************************************
/*!
	@file		mms101.h
	@brief		MMS101 Sample Source Header File

				copyright: MITSUMI Electric Co., LTD.
	@attention	none
	@warning	MITSUMI CONFIDENTIAL
*/
//******************************************************************************
/*******************************************************************************
* History : DD.MM.YYYY Version  Description
*         : 07.10.2021 1.0.0.0  First Release
*******************************************************************************/
#ifndef __MMS101_H__
#define __MMS101_H__

//==============================================================================
//{### MODULES USED
//==============================================================================
#ifdef __MMS101_C__
	#define EXT_MMS101
#else
	#define EXT_MMS101 extern
#endif

//==============================================================================
//{### DEFINES AND MACROS
//==============================================================================
	#define INTERVAL_TIME_US 		1000 	// (>= 950)
	#define RESTART_INTERVAL_NUM 	0

	#define WAIT_US_1ST_CONV 6000

	#define MEAS_NUM_MAX 2000000000

	#define RIGHT_BIT_SHIFT_11 2048		//2^11
	
	#define MMS101_COEFF_NUM_MAX 6
	#define MMS101_NVM_BANK_NUM 4
	
	#define DEV_FX 0
	#define DEV_FY 1
	#define DEV_FZ 2
	#define DEV_MX 3
	#define DEV_MY 4
	#define DEV_MZ 5

	// AFE Command
	#define MMS101_CMD_RESET				0x72				//!< Reset

	#define MMS101_CMD_STATUS				0x80				//!< Status

	#define MMS101_CMD_SHUTDOWN				0x90				//!< Shutdown
	#define MMS101_CMD_STANDBY				0x92				//!< Standby
	#define MMS101_CMD_IDLE					0x94				//!< Idle

	#define MMS101_CMD_ACTIVE0				0xA0				//!< Active Mode 0
	#define MMS101_CMD_ACTIVE1				0xA2				//!< Active Mode 1
	#define MMS101_CMD_ACTIVE2				0xA4				//!< Active Mode 2
	#define MMS101_CMD_ACTIVE3				0xA6				//!< Active Mode 3

	#define MMS101_CMD_RESULT0				0xC0				//!< read Physical Value
	#define MMS101_CMD_RESULT1				0xC2				//!< read Temperature
	#define MMS101_CMD_RESULT2				0xC4				//!< read Calibration Value
	#define MMS101_CMD_RESULT3				0xC6				//!< read Physical Value 2

	#define MMS101_CMD_READ_REG				0xD0				//!< Read Register
	#define MMS101_CMD_READ_NVM				0xD6				//!< Read NVM

	#define MMS101_CMD_WRITE_REG			0xE0				//!< Write Register

	// AFE Register Address
	#define MMS101_REG_BANK_CHK     		0x54

//==============================================================================
//{### TYPEDEFS AND STRUCTURES
//==============================================================================
	// Structure for matrix calculation
	typedef struct{
		uint8_t bitShift;								// Bit shift value
		int32_t coeff[MMS101_COEFF_NUM_MAX];			// Matrix calculation coefficient
		int32_t adcData;								// AD value
		int32_t output;									// Matrix calculation result 
	}mms101_data_t;

//==============================================================================
//{### PROTOTYPE / GLOBAL FUNCTIONS
//==============================================================================
	EXT_MMS101 int mms101_bootload(void);
	EXT_MMS101 int mms101_start(void);
	EXT_MMS101 int mms101_read_adc(void);
	EXT_MMS101 void mms101_calc_matrix(void);
	EXT_MMS101 int mms101_restart(void);
	EXT_MMS101 void mms101_usage(void);

//==============================================================================
//{### VARIABLES
//==============================================================================
	EXT_MMS101 mms101_data_t mms101_data[AFE_NUM_MAX]; 						// Structure of matrix calculation
	EXT_MMS101 struct timeval startTime;
	EXT_MMS101 struct timeval preGetTime;
	EXT_MMS101 uint32_t measureRestartLimit;
	EXT_MMS101 uint32_t measureCount;

	#ifdef __MMS101_C__
		uint8_t nvm_address_map[] = {0x5A, 0x5D, 0x60, 0x6C, 0x6F, 0x72};	// start address of matrix operation correction coefficients
	#else
		extern uint8_t nvm_address_map[MMS101_COEFF_NUM_MAX];
	#endif

#endif 	// __MMS101_H__

