//******************************************************************************
/*!
	@file		mms101_spi.h
	@brief		SPI Module Function Header File

				copyright: MITSUMI Electric Co., LTD.
	@attention	none
	@warning	MITSUMI CONFIDENTIAL
*/
//******************************************************************************
/*******************************************************************************
* History : DD.MM.YYYY Version  Description
*         : 07.10.2021 1.0.0.0  First Release
*******************************************************************************/
#ifndef __MMS101_SPI_H__
#define __MMS101_SPI_H__

#ifdef __MMS101_SPI_C__
	#define EXT_MMS101_SPI
#else
	#define EXT_MMS101_SPI extern
#endif

//==============================================================================
//{### MODULES USED
//==============================================================================

//==============================================================================
//{### DEFINES AND MACROS
//==============================================================================
#define AFE_NUM_MAX 	6

#define SPI_DATA_SIZE 	32

#define DEV_SPI_PATH "/dev/spidev0.0"

#define SPI_MODE 		SPI_MODE_3 		// SPI MODE=3
#define SPI_SPEED_HZ 	5000000 		// 5MHz
#define SPI_DELAY_USECS 0
#define SPI_SPI_BITS 	8
#define SPI_CS_CHANGE 	0

#define DEV_GPIO_PATH1 "/sys/class/gpio"
#define DEV_GPIO_PATH2 "/sys/class/gpio/gpio"

#define CSB0_GPIO_NO	"18"
#define CSB1_GPIO_NO	"23"
#define CSB2_GPIO_NO	"24"
#define CSB3_GPIO_NO	"25"
#define CSB4_GPIO_NO	"12"
#define CSB5_GPIO_NO	"5"

//==============================================================================
//{### TYPEDEFS AND STRUCTURES
//==============================================================================
typedef struct{
	int fd;
	int fd_csb[AFE_NUM_MAX];
	uint8_t mode;
	struct spi_ioc_transfer tr[1];
} spi_device_t;

//==============================================================================
//{### PROTOTYPE / GLOBAL FUNCTIONS
//==============================================================================
EXT_MMS101_SPI int spi_init(spi_device_t *spi_device);
EXT_MMS101_SPI int spi_csb_init(spi_device_t *spi_device);
EXT_MMS101_SPI int spi_csb_open(spi_device_t *spi_device);
EXT_MMS101_SPI int spi_csb_close(spi_device_t *spi_device);
EXT_MMS101_SPI int spi_enable(uint8_t devNo, spi_device_t *spi_device);
EXT_MMS101_SPI int spi_disable(uint8_t devNo, spi_device_t *spi_device);
EXT_MMS101_SPI int spi_close(spi_device_t *spi_device);
EXT_MMS101_SPI int spi_send_data(uint8_t devNo, spi_device_t *spi_device, uint8_t *txbuf, uint8_t txlen);
EXT_MMS101_SPI int spi_receive_data(uint8_t devNo, spi_device_t *spi_device, uint8_t *rxbuf, uint8_t rxlen);
EXT_MMS101_SPI int spi_send_after_receive_data(uint8_t devNo, spi_device_t *spi_device, uint8_t *txbuf, uint8_t txlen, uint8_t *rxbuf, uint8_t rxlen);
EXT_MMS101_SPI int spi_check_busy(spi_device_t *spi_device, long timeout);
EXT_MMS101_SPI int getElapsedTimeUs(struct timeval *tvStart, struct timeval *tvUpdate);
EXT_MMS101_SPI double getElapsedTime(struct timeval *tvStart, struct timeval *vUpdate);

//==============================================================================
//{### VARIABLES
//==============================================================================
#ifdef __MMS101_SPI_C__
char csGpioNo[AFE_NUM_MAX][3] = {CSB0_GPIO_NO, CSB1_GPIO_NO, CSB2_GPIO_NO, CSB3_GPIO_NO, CSB4_GPIO_NO, CSB5_GPIO_NO};
#else
extern char csGpioNo[AFE_NUM_MAX][3];
#endif
EXT_MMS101_SPI spi_device_t spi_dev;
EXT_MMS101_SPI uint8_t tx_buf[SPI_DATA_SIZE];
EXT_MMS101_SPI uint8_t rx_buf[SPI_DATA_SIZE];

#endif 	// __MMS101_SPI_H__

